# trandecoder

**DOI:** [10.5281/zenodo.8092506](https://doi.org/10.5281/zenodo.8092506)

## Available Versions
- **Version 5.7.0**
  - [Download](https://zenodo.org/record/8092507/files/trandecoder_5.7.0.img)
  - **MD5:** `3fd0fd5deb8b567bb1c430d1d771ff3f`
  - **DOI:** [10.5281/zenodo.8092507](https://doi.org/10.5281/zenodo.8092507)
  - **Size:** 1168.60 MB
  - **Binaries:** 0 available

## Binaries (1 total)

```TransDecoder.wiki,TransDecoder.LongOrfs,TransDecoder.Predict,TransDecoder.lrgTests```
